| Title: | What the Package Does (One Line, Title Case) |
|---|---|
| Description: | What the package does (one paragraph). |
| Authors: | First Last [aut, cre] |
| Maintainer: | First Last <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.3.005 |
| Built: | 2026-05-22 18:55:17 UTC |
| Source: | https://github.com/ropensci-review-tools/dashboard |
Add additional columns to 'editors' data from rOpenSci's airtable database, and remove any "emeritus" editors.
add_editor_airtable_data(editors, airtable_id)add_editor_airtable_data(editors, airtable_id)
editors |
The 'data.frame' of editors returned as the "status" component from editor_status. |
airtable_id |
The 'id' string of the airtable table. |
A modified version of 'editors' with additional columns.
This is only slightly modified from review_history, through adding additional Airtable data to identify current editorial team.
community_data(airtable_id, quiet = FALSE)community_data(airtable_id, quiet = FALSE)
airtable_id |
ID of Airtable base |
quiet |
If 'FALSE', display progress information on screen. |
A named list with one element for each community member and integer values for total number of packages submitted; total number of reviews conducted; and an additional logical flag indicating whether or not that person is or was a member of the editorial team. These data are returned as a raw list, because they are processed directly in Javascript.
Note that is extracts data for all editors, including those who may not be part of current editorial team. Current team members can be identified from data returned from the editor_status function.
ed_rev_durations(nyears = 2)ed_rev_durations(nyears = 2)
nyears |
Length of time prior to current date over which average durations should be calculated. |
A ‘data.frame' with two columns of ’editor' and 'duration' in days.
Generate summary data of current and historical activities of all rOpenSci editors
editor_status(quiet = FALSE, aggregation_period = "quarter")editor_status(quiet = FALSE, aggregation_period = "quarter")
quiet |
If 'FALSE', display progress information on screen. |
aggregation_period |
The time period for aggregation of timeline for editorial loads. Must be one of "month", "quarter", or "semester". |
A list of four items:
'status', a 'data.frame' of current editor status, with one row per editor and some key statistics.
'timeline_total', a 'data.frame' representing the timelines for each editor of total concurrent editorial load.
'timeline_new', a 'data.frame' representing the timelines for each editor of editorial load of new issues opened in each time period (default of quarter-year.
'reviews', a 'data.frame' with one row per issue and some key statistics.
Data are obtained both from airtable and current slack status. If either of these indicate that an editor is away, on vacation, or otherwise unavailable, then the 'away' column will be set to 'TRUE'.
editor_vacation_status(airtable_id)editor_vacation_status(airtable_id)
airtable_id |
The 'id' string of the airtable table. |
A 'data.frame' with one row per editor and information on current vacation status.
Generate historical data on logged review times in hours from airtable database.
rev_hours_airtable()rev_hours_airtable()
A 'data.frame' with one row per issue and some key statistics.
This is a reduced version of the 'reviews_gh_data()' function, which returns data only on dates of issue opening and closing, to be used to generate historical patterns.
review_history(quiet = FALSE)review_history(quiet = FALSE)
quiet |
If 'FALSE', display progress information on screen. |
(Invisibly) A 'data.frame' with one row per issue and some key statistics.
Generate a summary report for incoming Editor-in-Charge of current state of all open software-review issues.
review_status(open_only = TRUE, browse = TRUE, quiet = FALSE)review_status(open_only = TRUE, browse = TRUE, quiet = FALSE)
open_only |
If 'TRUE' (default), only extract information for currently open issues. |
browse |
If 'TRUE' (default), open the results as a DT 'datatable' HTML page in default browser. |
quiet |
If 'FALSE', display progress information on screen. |
A 'data.frame' with one row per issue and some key statistics.